@@ -144,7 +144,8 @@ class CloudPods:
             "os_arch": arch,
             "nets": nets,
             "prefer_region": "default",
-            "bios": bios
+            "bios": bios,
+            "schedtags": [{"id": "094cfe0f-7fbf-451f-879d-d44151539240", "strategy": "exclude"}],
         }
         if reset_new_password:
             server["password"]=reset_new_password
